create_new_trial_data: Data on new trial in target population

View source: R/create_new_trial_data.R

create_new_trial_dataR Documentation

Data on new trial in target population

Description

Creates a vector containing data on the new trial in the target population. This may be hypothetical data in the planning stage.

Usage

create_new_trial_data(n_total, est, se)

Arguments

n_total

The total sample size.

est

Treatment effect estimate.

se

Standard error of the treatment effect estimate.

Value

A numeric vector with data on the new trial, incl. quantiles of an assumed normal data likelihood.

See Also

[create_posterior_data()] and [create_tipmap_data()].

Examples

new_trial_data <- create_new_trial_data(
  n_total = 30, est = 1.27, se = 0.95
)


tipmap documentation built on June 5, 2026, 9:12 a.m.