get_model_input_1exp: Transform cumulative probabilities to fit beta distributions

View source: R/get_model_input_1exp.R

get_model_input_1expR Documentation

Transform cumulative probabilities to fit beta distributions

Description

Transform cumulative probabilities to fit beta distributions

Usage

get_model_input_1exp(cum_probs, w = NULL)

Arguments

cum_probs

Numeric vector, containing cumulative probabilities of weights for one expert, as elicited through the roulette method. Each element of the vector represents one bin in the grid.

w

Numeric vector, upper interval limit of bin (defaults to 1:length(cum_probs) / length(cum_probs)).

Value

Dataframe to be used as input to fit beta distributions by [fit_beta_1exp()].

See Also

[get_cum_probs_1exp()] and [fit_beta_1exp()].

Examples

chips <- c(0, 2, 3, 2, 1, 1, 1, 0, 0, 0)
x <- get_cum_probs_1exp(chips)
print(x)
y <- get_model_input_1exp(x)
print(y)


tipmap documentation built on June 5, 2026, 9:12 a.m.